@@ -3,6 +3,11 @@
 #include "iterators_b3s23.h"
 namespace apg {
 
+    std::string get_zoi(std::string rule) {
+        (void) rule;
+        return "99";
+    }
+
     int rule2int(std::string rule) {
         if (rule == "b3s23") { return 0; }
         return -1;
