@@ -2,6 +2,8 @@ family = 4
 bitplanes = 1
 mantissa = {0, 1}
 
+from .exceptions import NonCanonicalError
+
 def create_rule(rulestring):
 
     isotrope(rulestring)
@@ -72,8 +74,6 @@ def str2tab(rulestring, hexagonal='unknown'):
 
             raise ValueError('Error: "%s" does not match the regex "%s"' % (rulestring, regex))
 
-        # raise NotImplementedError("Hexagonal rules are currently unsupported")
-
     popcounts = [0, 1, 1, 2, 1, 2, 2, 3, 1, 2, 2, 3, 2, 3, 3, 4]
     lord2 = []
 
@@ -140,9 +140,7 @@ def str2tab(rulestring, hexagonal='unknown'):
                 canstring += a
 
     if (rulestring != canstring):
-        print('Please re-run the code with the canonical rulestring:')
-        print(('./recompile.sh --rule \033[36;1m%s\033[0m' % canstring))
-        raise ValueError('Error: %s is a non-canonical version of %s' % (rulestring, canstring))
+        raise NonCanonicalError('%s is a non-canonical version of %s' % (rulestring, canstring))
 
     return lord2
 
