@@ -1,5 +1,6 @@
 #include "pattern2.h"
 #include "streamlife.h"
+#include "soup/hashsoup.h"
 #include "ssplit.h"
 #include <new>
 
@@ -124,6 +125,13 @@ extern "C"
         return new(std::nothrow) apg::pattern(lab, std::string(rle), std::string(rule));
     }
 
+    void* Hashsoup(void* lt, const char *rule, const char *symmetry, const char *seed) {
+        auto lab = reinterpret_cast<apg::lifetree_abstract<uint32_t>*>(lt);
+        std::vector<apg::bitworld> vbw;
+        vbw.push_back(apg::hashsoup(std::string(seed), std::string(symmetry)));
+        return new(std::nothrow) apg::pattern(lab, vbw, std::string(rule));
+    }
+
     void* AdvancePattern(void* pat, int numgens, uint64_t exponent) {
         auto ppat = reinterpret_cast<apg::pattern*>(pat);
         return new(std::nothrow) apg::pattern(ppat->advance2(numgens, exponent));
