@@ -77,7 +77,13 @@ namespace apg {
         hypernode<I> getchild(hypernode<I> parent, uint32_t n) {
             return htree.getchild(parent, n);
         }
+
         int rulestring_to_integer(std::string rulestring) {
+
+            if ((rulestring.length() >= 1) && (rulestring[0] == '*')) {
+                return rulestring.length() - 1;
+            }
+
             return rule2int(rulestring);
         }
 
