@@ -589,7 +589,7 @@ namespace apg {
             ss << ((rep == "#") ? "ov_" : "x");
 
             if ((p == 1) && (dx == 0) && (dy == 0)) {
-                ss << "s" << x.flatlayer(0).population();
+                ss << "s" << (this->popcount((1 << 30) + 3));
             } else {
                 if (dx == 0 && dy == 0) {
                     ss << "p" << p;
@@ -692,6 +692,23 @@ namespace apg {
 
         }
 
+        // -----------------------------------------
+        // upattern-like functionality:
+        // -----------------------------------------
+        int totalPopulation() {
+            return this->popcount((1 << 30) + 3);
+        }
+        void advance(int rule, int history, uint64_t generations) {
+            std::string rulestr(rule + 1, '*');
+            if (history & 1) { rulestr += "History"; }
+            hnode = lab->advance(hnode, rulestr, generations);
+            lab->sethandle(ihandle, hnode);
+        }
+        uint64_t totalHash(int radius) {
+            hypernode<I> rect = lab->rectangle(-16 * radius, -16 * radius, 32 * radius, 32 * radius);
+            return lab->boolean_universe(hnode, rect, 0).index;
+        }
+        // -----------------------------------------
     };
 
     template<typename I>
