@@ -145,7 +145,7 @@ namespace apg {
         vbw.world[std::pair<int32_t, int32_t>(0, 1)] = uint64_vreflect(b);
         vbw.world[std::pair<int32_t, int32_t>(1, 1)] = uint64_vreflect(a);
 
-        if (symmetry == "D2_xo") { return vbw; }
+        if (symmetry == "D2_xo") { return shift_bitworld(vbw, 0, -15); }
 
         if (symmetry == "D2_+1") { bw += shift_bitworld(vbw, 0, -15); return bw; }
         if (symmetry == "D2_+2") { bw += shift_bitworld(vbw, 0, -16); return bw; }
@@ -188,8 +188,32 @@ namespace apg {
             inflations += 1;
             symmetry = symmetry.substr(1);
         }
+
+        bool rot3 = true;
+        bool rot2 = false;
+
+        if (full_symmetry == "C6") {
+            symmetry = "C2_1";
+        } else if (full_symmetry == "D12") {
+            symmetry = "D2_x"; rot2 = true;
+        } else if (full_symmetry == "C3_1") {
+            symmetry = "C1";
+        } else if (full_symmetry == "D6_1") {
+            symmetry = "D2_x";
+        } else if (full_symmetry == "D6_1o") {
+            symmetry = "D2_xo";
+        } else {
+            rot3 = false;
+        }
+
         // std::cout << inflations << " " << symmetry << std::endl;
         bitworld bw = hashsoup_inner(prehash, symmetry);
+
+        if (rot3) {
+            bw = shift_bitworld(bw, -15, 0).inplace_rot3();
+            if (rot2) { bw.inplace_rot2(); }
+        }
+
         for (uint64_t i = 0; i < inflations; i++) {
             bw = bw.inflate();
         }
